<?php

namespace Tests\Feature;

use Tests\TestCase;
use Illuminate\Http\UploadedFile;
use Illuminate\Support\Facades\Storage;
use Illuminate\Foundation\Testing\DatabaseTransactions;

class UserTest extends TestCase
{
    use DatabaseTransactions;

    public function setUp()
    {
        parent::setUp();
        $this->user = factory('App\Models\User')->create();
    }

    /** @test */
    public function get_all_users()
    {
        $users = factory('App\Models\User', 5)->create();
        $response = $this->actingAs($this->user)->get('users');
        $response->assertJsonFragment([
            'status'     => 'success',
            'username'   => $users[0]->username,
            'name'       => $users[0]->name,
        ]);
    }

    /** @test */
    public function user_can_upload_avatar_image()
    {
        $this->actingAs($this->user);
        Storage::fake('public');
        $this->post('users/'.$this->user->username.'/avatar', [
            'avatar' => UploadedFile::fake()->image('avatar.png'),
        ]);
        $this->assertEquals(env('APP_URL').'/storage/avatars/'.$this->user->username.'.png', auth()->user()->avatar);
        Storage::disk('public')->assertExists('avatars/'.$this->user->username.'.png');
    }
}
